from hydra_client import HydraAdmin, exceptions
from promise import Promise
from promise.dataloader import DataLoader
import logging

module_logger = logging.getLogger("backend.hydra")

class oAuth2ClientLoader(DataLoader):
    def __init__(self, hydra_admin_url):
        super().__init__()
        self.hydra = HydraAdmin(hydra_admin_url)
        self.logger = logging.getLogger("backend.hydra.oAuth2ClientLoader")

    # overrides DataLoader.batch_load_fn
    def batch_load_fn(self, client_ids):
        return Promise.resolve([self._get_hydra_client(client_id) for client_id in client_ids])

    def _get_hydra_client(self, client_id):
        try:
            return self.hydra.client(id=client_id)
        except exceptions.NotFound as error:
            self.logger.error(
                "requesting resource from hydra-admin API failed - hydra oAuth client {0} not found".format(client_id))
            return None
        except exceptions.ConnectionError as error:
            self.logger.critical("hydra-admin API server is not reachable")
            self.clear_all()
            return None
