from database.database import Base
from flask_security import UserMixin, RoleMixin
from sqlalchemy import create_engine
from sqlalchemy.orm import relationship, backref
from sqlalchemy import Boolean, DateTime, Column, Integer, \
                       String, ForeignKey, Unicode


class RolesUsers(Base):
    __tablename__ = 'oas_roles_users'
    id = Column(Integer(), primary_key=True)
    user_id = Column('user_id', Integer(), ForeignKey('oas_user.id'))
    role_id = Column('role_id', Integer(), ForeignKey('oas_role.id'))


class ApplicationsUsers(Base):
    __tablename__ = 'oas_applications_users'
    id = Column(Integer(), primary_key=True)
    user_id = Column('user_id', Integer(), ForeignKey('oas_user.id'))
    application_id = Column('application_id', Integer(), ForeignKey('oas_application.id'))


class Role(Base, RoleMixin):
    __tablename__ = 'oas_role'
    id = Column(Integer(), primary_key=True)
    name = Column(String(80), unique=True)
    description = Column(String(255))


class Application(Base):
    __tablename__ = 'oas_application'
    id = Column(Integer, primary_key=True)
    name = Column(String(80), unique=True)
    description = Column(Unicode(1000))


class User(Base, UserMixin):
    __tablename__ = 'oas_user'
    id = Column(Integer, primary_key=True)
    email = Column(String(255), unique=True)
    username = Column(String(255))
    password = Column(String(255))
    active = Column(Boolean())
    roles = relationship('Role', secondary='oas_roles_users',
                         backref=backref('users', lazy='dynamic'))
    applications = relationship('Application', secondary='oas_applications_users',
                                backref=backref('users', lazy='dynamic'))
