### Prerequisites

In order to run this application, npm (>= 6.9.0) needs to be installed. As the application
will authenticate its users using OpenID Connect, an OpenID Connect Provider and an OpenID Client
needs to be set up.
This application was developed to be used with [an OpenID Connect single sign on system](https://open.greenhost.net/openappstack/single-sign-on).

### Configuration

Configuration has to be specified in `nuxt.config.js`. Setting the OpenID Connect parameters
correctly is essential for the login process to work. Note that there are also environment
variables that can be set instead of changing the defaults in `nuxt.config.js`.
In case you want to configure the application by using those variables you have to set and export them like this:
```
export HOST=sso.example.net
export BACKEND_API_URL=http://oas.localhost:5002/graphql
export BASE_URL=http://sso.example.net:3000
export HYDRA_BASE_URL=http://oas.example.net:4444
export AUTHORIZE_URL=http://oas.example.net:4444/oauth2/auth
export USERINFO_URL=http://oas.example.net:4444/userinfo
export ACCESS_TOKEN=http://oas.example.net:4444/oauth2/token
export REDIRECT_URL=http://sso.example.net:3000/callback
export OAUTH_CLIENT_ID=user-panel
export OAUTH_CLIENT_SECRET=secret_secret
```

Instead of using your own OpenID Provider, you can also use external providers. For details on how
to configure authentication for external providers like GitHub, please refer to [the nuxt-oauth documentation](https://auth.nuxtjs.org/schemes/oauth2.html)

### Installation

Installation is done with `npm`. Execute the following commands after changing to the user-panel/frontend
directory.
```
cd user-panel/frontend
npm install --production
```

Start the application in debug mode with

```
npm run dev
```

Build and run the application for production use with

```
npm run build
npm run start
```

or 

```
npm build-start
```


### Usage

Navigate your browser to the `server` URL, that you specified in `nuxt.config.js`. The default port
is 3000.

As an administrator you can access the user backend API by accessing the api endpoint
that is exposed by the user-panel at `/api/admin/graphql`. If you run your backend server in
development mode, you can access the `GraphiQL` web interface of the backend by navigating
your browser to the URL.
Note that you need to manually provide a cookie containing the Bearer token in case you don't
access the api with a browser that automatically includes your cookie in the request.
Passing the token as a GET or POST variable is not supported.


### Testing

The test folder includes end to end tests that you can run from your workstation to check if
your setup is working properly especially in case you want to make changes to the code.

#### Prerequisites

E2E tests are executed with chromedriver. Make sure that you have a supported version
of chromium installed. To downgrade the chromium version that is used in the tests, change
the version number in `package.json` [accordingly](https://www.npmjs.com/package/chromedriver).

In order to run the tests you also need to install additional node packages.
The development and testing dependencies can be installed with

```
npm install # without --production
```
The tests will use login credentials of 3 different users.
 * Create a user that has the role `admin`and the application `user-panel` assigned to it.
 * Create a second user and only assign the  application `user-panel`.
 * Create a third user and don't assign anything to it.

You can use the utility scripts provided in the backend folder of this repo to create the users
applications and roles. To do that execute:

```
bash ../backend/utils/create-application.bash user-panel
bash ../backend/utils/create-role.bash admin
bash ../backend/utils/create-user.bash admin adminadmin admin@example.net
bash ../backend/utils/create-user.bash testuser testtest testuser@example.net
bash ../backend/utils/create-user.bash testuser2 testtest testuser2@example.net
bash ../backend/utils/assign-role.bash admin admin
bash ../backend/utils/grant-access.bash admin user-panel
bash ../backend/utils/grant-access.bash testuser user-panel
```
After that configure the values in `test/nightwatch_globals.js` to match the usernames and
passwords.

#### Run the tests

To run the tests, execute `npm run test`
