const nuxtConfig = require('../../nuxt.config')
const { Issuer, TokenSet } = require('openid-client')



const authenticateWithToken = function (req, res, next) {
  // Configure openID-Connect client to verify tokens
  // use the configuration that is supplied in ~/nuxt.config.js
  const authStrategy = nuxtConfig.auth.strategies["oas"]
  const openIdIssuer = new Issuer({
      authorization_endpoint: authStrategy.authorization_endpoint,
      token_endpoint: authStrategy.access_token_endpoint,
      userinfo_endpoint: authStrategy.userinfo_endpoint
  });
  const openIdClient = new openIdIssuer.Client({
      client_id: authStrategy.client_id,
      client_secret: authStrategy.client_secret,
      redirect_uris: [authStrategy.redirect_uri],
      response_types: [authStrategy.response_type],
      grant_types: ["implicit"]
    })
  // Get the oAuth2.0 access token from the user request
  // The User cookies are forwarded to this middleware
  // by nuxt add parsed by the cookieParser module which
  // makes the cookies accessible via req.cookies
  const authToken = req.cookies['auth._token.oas']
  const tokenSet = new TokenSet(
    {
      access_token: authToken.slice("Bearer ".length),
      token_type: "Bearer"
    })
  // We don't trust the token beacuse we received it via
  // the request object which is created by the client.
  // In order to verify the token, we query the userinfo
  // endpoint using the provided token. If the OpenID
  // provider accepts the token, we know it's valid and
  // we will get the userinfo at the same time
  openIdClient.userinfo(tokenSet).then(function(userinfo){
    // Save our validated userinfo in the request object
    // for use in other express.js middleware functions
    req.user = {
      sid: userinfo.sid,
      roles: userinfo[nuxtConfig.auth.scopeKey]
    }
    if ( userinfo.hasOwnProperty('preferred_username')){
      req.user.name = userinfo.preferred_username;
    }
    else {
      req.user.name = userinfo.name
    }
    next()
  }).catch(function(error){
    res.status(403).send("Authentication failed: " + error)
  });
}

module.exports = authenticateWithToken
