import Lokka from 'lokka';
import Transport from 'lokka-transport-http';


export default class OpenAppStackModel {
  constructor(graphQlUrl){
    this.backendApiUrl = graphQlUrl;
    this.graphQlClient = new Lokka({
        transport: new Transport(this.backendApiUrl)
    });
  }
  allUsers(){
    return this.graphQlClient.query(`
      {
        allUsers{
          edges{
            node{
              username,
              email,
              applications{
                edges{
                  node{
                    name
                  }
                }
              },
              roles{
                edges{
                  node{
                    name
                  }
                }
              }
            }
          }
        }
      }`)
      .then( users => {
        return users;
      });
  }
  allApplications(){
    return this.graphQlClient.query(`
      {
        allApplications{
          edges{
            node{
              name,
              users{
                edges{
                  node{
                    username,
                    email
                  }
                }
              }
            }
          }
        }
      }`)
      .then( applications => {
        return applications;
      });
  }
  allRoles(){
    return this.graphQlClient.query(`
      {
        allRoles{
          edges{
            node{
              name,
              users{
                edges{
                  node{
                    username,
                    email
                  }
                }
              }
            }
          }
        }
      }`)
      .then( roles => {
        return roles;
      });
  }
  createUser(username, email, password){
    const vars = { username: username, email: email, password: password };
    const createUserMutation = `
        mutation createUser($username: String!, $email: String!, $password: String!){
          createUser(
            username: $username,
            email: $email,
            password: $password
          ){
            user{ username, email }
          }
        }`;
    return this.graphQlClient.query(createUserMutation, vars)
      .then( user => {
        return user;
      });
  }
  editUser(username, email, password){
    const vars = { username: username, email: email, password: password };
    const editUserMutation = `
        mutation editUser($username: String!, $email: String, $password: String){
          editUser(
            username: $username,
            email: $email,
            password: $password
          ){
            ok
          }
        }`;
    return this.graphQlClient.query(editUserMutation, vars)
      .then( ok => {
        return ok;
      });
  }
  deleteUser(username){
    const vars = { username: username };
    const deleteUserMutation = `
        mutation deleteUser($username: String!){
          deleteUser(
            username: $username
          ){
            ok
          }
        }`;
    return this.graphQlClient.query(deleteUserMutation, vars)
      .then( ok => {
        return ok;
      });
  }
  addRoleToUser(username, role){
    const vars = { username: username, role: role };
    const addRoleToUserMutation = `
        mutation addRoleToUser($username: String!, $role: String!){
          addRoleToUser(
            username: $username,
            role: $role
          ){
            user{ username }
          }
        }`;
    return this.graphQlClient.query(addRoleToUserMutation, vars)
      .then( ok => {
        return ok;
      });
  }
  addApplicationToUser(username, application){
    const vars = { username: username, application: application };
    const addApplicationToUser = `
        mutation addApplicationToUser($username: String!, $application: String!){
          addApplicationToUser(
            username: $username,
            application: $application
          ){
            user{ username }
          }
        }`;
    return this.graphQlClient.query(addApplicationToUser, vars)
      .then( ok => {
        return ok;
      });
  }
  removeRoleFromUser(username, role){
    const vars = { username: username, role: role };
    const removeRoleFromUser = `
        mutation removeRoleFromUser($username: String!, $role: String!){
          removeRoleFromUser(
            username: $username,
            role: $role
          ){
            ok
          }
        }`;
    return this.graphQlClient.query(removeRoleFromUser, vars)
      .then( ok => {
        return ok;
      });
  }
  removeApplicationFromUser(username, application){
    const vars = { username: username, application: application };
    const removeApplicationFromUser = `
        mutation removeApplicationFromUser($username: String!, $application: String!){
          removeApplicationFromUser(
            username: $username,
            application: $application
          ){
            ok
          }
        }`;
    return this.graphQlClient.query(removeApplicationFromUser, vars)
      .then( ok => {
        return ok;
      });
  }
  user(username){
    const vars = { username: username };
    const getUser = `
        query getUser($username: String!){
          getUser(username: $username){
            username,
            email,
            applications {
              edges{node{name, logo, url, description}}
            },
            roles {
              edges{node{name}}
            }
          }
        }`
    return this.graphQlClient.query(getUser, vars)
      .then( user => {
        return user;
      });
  }
}
