module.exports = {
  'Login' : function (browser) {
    const index = browser.page.index();
    const login = browser.page.login()
    index
      .navigate()
      .waitForElementVisible('@loginButton')
      .click("@loginButton")
    login
      .waitForElementVisible('@loginButton')
      .click("@loginButton")
      .waitForElementVisible('input[name=username]')
      .setValue('input[name=username]', browser.globals.adminUsername)
      .setValue('input[name=password]', browser.globals.adminPassword)
      .click('input[name=submit]')
    index
      .waitForElementVisible('@logoutButton')
  },
  'Index page layout after login with admin user' : function (browser) {
    const index = browser.page.index();
    const navbar = index.section.navbar;
    index.navigate()
    navbar
      .assert.elementPresent('@oidc')
      .assert.elementPresent('@users')
  },
  'Inspect user admin page components' : async function(browser){
    const users = browser.page.users();
    const roles = users.section.leftSidebar;
    const addUser = users.section.addUser;
    const editUsers = users.section.editUsers;
    const editUserFields = editUsers.section.fields;
    const newUsername = "newTestUser"
    users.navigate()
    // Testing if role selector "admin" and "all" are present
    roles
      .waitForElementVisible("@all")
      .assert.containsText("@all", "All")
      .assert.containsText("@admin", "admin")
    // Test if the the role selectors work as expected
      .verify.containsText('@userCount', '3')
      .click("@all")
    const allUserRows = await editUsers.api.elements('@rows')
    editUsers
      .verify.strictEqual(allUserRows.result.value.length, 3, "Testing if there are 3 user rows to edit")
    roles
      .verify.containsText('@adminCount', '1')
      .click("@admin")
    const adminUserRows = await editUsers.api.elements('@rows')
    editUsers
      .verify.strictEqual(adminUserRows.result.value.length, 1, "Testing if there is 1 admin user to edit")
    editUsers
      .assert.containsText("@username", browser.globals.adminUsername )
    // Test if the add user component is present
    // Submit a username but don't save the user yet
    addUser
      .assert.containsText("@addUserButton", "Add user")
      .click("@addUserButton")
      .waitForElementVisible("@inputUsername")
      .assert.hidden("@addUserButton")
      .assert.visible("@submitUsername")
      .setValue("@inputUsername", browser.globals.adminUsername)
      .assert.attributeEquals("@inputUsername", "aria-invalid", "true")
      .assert.cssClassPresent("@inputUsername", "is-invalid")
      .setValue("@inputUsername", newUsername)
      .assert.cssClassPresent("@inputUsername", "is-valid")
      .click("@submitUsername")
      .assert.hidden("@inputUsername")
    // Testing if the user edit section of the page looks as expected
    // Test if the header fields are visible
    editUsers
      .assert.visible("@header")
      .assert.containsText("@header", "Username")
      .assert.containsText("@header", "Password")
      .assert.containsText("@header", "Email")
      .assert.visible("@rows")
    // Test if the user fields are visible
    editUsers
      .assert.visible("@username")
      .assert.visible("@password")
      .assert.visible("@email")
    // Test if the all the buttons present to edit the user
    editUsers
      .assert.visible("@delete")
      .assert.hidden("@save")
    editUsers.setValue("@email", "trigger@change.event")
    editUsers.assert.visible("@save")
  },
  'Add and delete a user' : async function(browser){
    const users = browser.page.users();
    const roles = users.section.leftSidebar;
    const addUser = users.section.addUser;
    const editNewUser = users.section.editNewUser;
    const editUsers = users.section.editUsers;
    const newUsername = "newTestUser"
    const newPassword = "newTestUser"
    const newEmail = "test42@example.net"
    users.navigate()
    users.createUser(newUsername, newPassword, newEmail)
    addUser.waitForElementVisible("@addUserButton")
    const allUserRows = await editUsers.api.elements('@rows')
    editUsers
      .verify.strictEqual(allUserRows.result.value.length, 4, "Testing if there are 4 user rows to edit")
    roles
      .verify.containsText('@userCount', '4')
    const newTestUser = editUsers.section.newTestUser;
    newTestUser.assert.containsText("@username", newUsername)
    newTestUser.assert.value("@email", newEmail)
    newTestUser.click("@delete")
    roles
      .verify.containsText('@userCount', '3')
  }
};
