module.exports = {
  'Login' : function (browser) {
    const index = browser.page.index();
    const login = browser.page.login()
    index.navigate()
      .waitForElementVisible('@loginButton')
      .click("@loginButton")
    login
      .waitForElementVisible('@loginButton')
      .click('@loginButton')
      .waitForElementVisible('input[name=username]')
      .setValue('input[name=username]', browser.globals.userUsername)
      .setValue('input[name=password]', browser.globals.userPassword)
      .click('input[name=submit]')

    index
      .waitForElementVisible('@logoutButton')
      .assert.containsText('@logoutButton', 'Logout')
  },
  'Index page layout after login' : function (browser) {
    const index = browser.page.index();
    const navbar = index.section.navbar;
    const usermenu = navbar.section.usermenu;
    index.navigate()
    usermenu
      .assert.containsText("@userNameLabel", browser.globals.userUsername)
      .assert.elementNotPresent("@logoutButton")
      .click("@userNameLabel")
      .assert.visible("@logoutButton")
      .assert.visible("@profileButton")
    navbar
      .assert.elementPresent('@oidc')
      .assert.elementNotPresent('@users')
  },
  'Change Profile settings' : function (browser) {
    const profile = browser.page.profile();
    const editProfile = profile.section.editProfile;
    const index = browser.page.index();
    const navbar = index.section.navbar;
    const login = browser.page.login()
    const usermenu = navbar.section.usermenu;
    const newEmail = "newemail@example.net";
    const oldEmail = "oldemail@example.net";
    const newPassword = "newPassword";
    profile.navigate()
    editProfile
      .assert.containsText("@username", browser.globals.userUsername)
      .clearValue("@email")
      .setValue("@email", newEmail)
      .setValue('@password', newPassword)
      .click("@save")
    usermenu.click("@userNameLabel")
      .click("@logoutButton")
    index.assert.visible('@loginButton')
    login.navigate()
      .waitForElementVisible('@loginButton')
      .click('@loginButton')
      .waitForElementVisible('input[name=username]')
      .setValue('input[name=username]', browser.globals.userUsername)
      .setValue('input[name=password]', newPassword)
      .click('input[name=submit]')
    index
      .waitForElementVisible('@logoutButton')
    profile.navigate()
    editProfile
      .assert.value("@email", newEmail)
    editProfile
      .clearValue("@email")
      .setValue("@email", oldEmail)
      .setValue("@password", browser.globals.userPassword)
      .submitForm("@password")
  },
  'Logout' : function (browser) {
    const index = browser.page.index();
    const navbar = index.section.navbar;
    const usermenu = navbar.section.usermenu;
    index.navigate()
    usermenu.click("@userNameLabel")
      .click("@logoutButton")
    index.assert.visible('@loginButton')
  },
  'Login without app permissions' : function (browser) {
    const index = browser.page.index();
    const navbar = index.section.navbar;
    const login = browser.page.login()
    index.navigate()
    navbar.click("@loginButton")
    login
      .waitForElementVisible('@loginButton')
      .click('@loginButton')
      .waitForElementVisible('input[name=username]')
      .setValue('input[name=username]', browser.globals.userWithoutAppPermissionUsername)
      .setValue('input[name=password]', browser.globals.userWithoutAppPermissionPassword)
      .click('input[name=submit]')
      .assert.containsText('body', "Failed to login")
  },
  'List of usable application is visible after login' : function(browser){
    const index = browser.page.index();
    const apps = index.section.apps;
    const login = browser.page.login()
    index.navigate()
      .click("@loginButton")
    login
      .click('@loginButton')
      .setValue('input[name=username]', browser.globals.userUsername)
      .setValue('input[name=password]', browser.globals.userPassword)
      .click('input[name=submit]')
    index.assert.visible('@apps')
    apps
      .assert.visible('@title')
      .assert.visible('@logo')
      .assert.visible('@button')
      .assert.visible('@logo')
      .assert.containsText('@title', "user-panel")
      .assert.attributeEquals('@button', 'href', index.url())
      .assert.attributeEquals('@logo', 'src', index.url()+"favicon.ico")
  }
};
